# geo-track-analyzer

Geo-Track-Analyzer aims to define a common interface for analyzing and visualizing geospacial data tracks from various sources.



<table border="1">
  <tbody>
    <tr>
      <td>Package</td>
      <td>
        <a href="https://pypi.org/project/geo-track-analyzer/">
            <img alt="PyPI - Version" src="https://img.shields.io/pypi/v/geo-track-analyzer">
        </a>
        <a href="https://pypi.org/project/geo-track-analyzer/">
            <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/geo-track-analyzer">
        </a>
      </td>
    </tr>
    <tr>
      <td>Meta</td>
      <td>
        <a href="https://github.com/kschweiger/track_analyzer/blob/main/LICENSE">
            <img alt="PyPI - License" src="https://img.shields.io/pypi/l/geo-track-analyzer">
        </a>
        <a href="https://docs.astral.sh/ruff/">
            <img alt="Linting - Ruff" src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json">
        </a>
        <img alt="Types - Mypy" src="https://img.shields.io/badge/types-Mypy-blue.svg">
      </td>
    </tr>
    <tr>
      <td>CI</td>
      <td>
        <a href="https://github.com/kschweiger/track_analyzer/actions/workflows/test.yml">
            <img src="https://github.com/kschweiger/track_analyzer/actions/workflows/test.yml/badge.svg" alt="Testing">
        </a>
        <a href="https://github.com/kschweiger/track_analyzer/actions/workflows/doc.yml">
            <img src="https://github.com/kschweiger/track_analyzer/actions/workflows/doc.yml/badge.svg" alt="Build Documentation">
        </a>
      </td>
    </tr>
  </tbody>
</table>